<?php

namespace report_page;

class report_filters
{
    private $report,
            $settings;
    
    function __construct($report)
    {
        $this->report = $report;
        
        $this->settings = new \settings($this->report['settings']);                  
    }
    
    
    
    function render()
    {        
        if($this->settings->get('filter_by_date')!=1 and $this->settings->get('filter_by_user')!=1) return '';
        
        $html = '            
            <form class="form-inline from-report-page-filters noprint" role="form">
                ' . 
                $this->render_fitler_by_date() . 
                $this->render_fitler_by_user() . 
                '
            </form>
            ';
        
        return $html;
    }
    
    function render_fitler_by_user()
    {
        global $app_users_cache, $report_page_filters;
        
        if($this->settings->get('filter_by_user')!=1) return '';
        
        $heading = strlen($this->settings->get('filter_by_user_heading')) ? $this->settings->get('filter_by_user_heading') : TEXT_USER;
        
        
        $allowed_groups = $this->settings->get('filter_by_user_allowed_groups');
                
        $choices = [];        
        foreach($app_users_cache as $user_id=>$user)
        {            
            if(is_array($allowed_groups) and !in_array($user['group_id'],$allowed_groups)) continue;
            
            $choices[$user_id] = $user['name']; 
        }
        
        $html = '
            <div class="form-group">
                <label>' . $heading . ': </label>
                ' . select_tag('filter_by_user',$choices,$report_page_filters['filter_by_user'],['class'=>'form-control input-large chosen-select']). '
            </div>    
            <script>
            $(function(){
              $("#filter_by_user").change(function(){
                load_report_page()
              })  
            })
            </script>
            ';
                
        return $html;
    }
    
    function render_fitler_by_date()
    {
        global $report_page_filters;
        
        if($this->settings->get('filter_by_date')!=1) return '';
        
        //settings
        $format = 'yyyy-mm-dd';
        $minViewMode = 'days';
        
        switch($this->settings->get('filter_by_date_mode'))
        {
            case 'day':
                $format = 'yyyy-mm-dd';
                $minViewMode = 'days';
                break;
            case 'month':
                $format = 'yyyy-mm';
                $minViewMode = 'months';
                break;
            case 'year':
                $format = 'yyyy';
                $minViewMode = 'years';
                break;
        }
        
        $heading = strlen($this->settings->get('filter_by_date_heading')) ? $this->settings->get('filter_by_date_heading') : TEXT_DATE;
        
        $html = '
            <div class="form-group">
                <label>' . $heading . ': </label>
                <div class="input-group input-medium date report-page-datepicker">' . input_tag('filter_by_date', $this->set_fitler_by_date_value(), ['class'=>'form-control','readonly'=>'readonly']) . '<span class="input-group-btn"><button class="btn btn-default date-set" type="button"><i class="fa fa-calendar"></i></button></span></div>    
            </div>
            
            <script>
            $(function(){
                $(function(){
                    $(".report-page-datepicker").datepicker({
                        rtl: App.isRTL(),
                        autoclose: true,
                        weekStart: app_cfg_first_day_of_week,
                        format: "' . $format . '",
                        clearBtn: false,
                        minViewMode: "' . $minViewMode . '",                      

                    }).on("changeDate",function(e){
                        load_report_page()
                    });
                })
            })
            </script>
            ';
        
        return $html;
    }
    
    function set_fitler_by_date_value()
    {
        global $report_page_filters;
        
        if(isset($report_page_filters['filter_by_date']))
        {
            return $report_page_filters['filter_by_date'];
        }
                        
        switch($this->settings->get('filter_by_date_mode'))
        {
            case 'day':
                return date('Y-m-d');
                break;
            case 'month':
                return date('Y-m');
                break;
            case 'year':
                return  date('Y');
                break;
            default:
                return  date('Y-m-d');
                break;
        }
    }
    
    static function set_filters()
    {
        global $report_page_filters;
        
        $filter_by_date = $_POST['filter_by_date'] ?? date('Y-m-d');
        
        $report_page_filters['filter_by_date'] = substr($filter_by_date,0,10);                
        $report_page_filters['filter_by_user'] = isset($_POST['filter_by_user']) ? (int)$_POST['filter_by_user'] : 0;
    }
    
    
}
